rename: rename

View source: R/rename.R

renameR Documentation

rename

Description

This function will create a directory if it doesnt exist, then copy the file and finally rename it. Most functions I have found will move the file and therein delete it. Which this function avoids.

Usage

rename(from, to)

Arguments

from

path where the files are coming from

to

path where you want the files to go to


alapo/mtr documentation built on April 4, 2022, 8:24 a.m.