resave: resave

View source: R/resave.R

resaveR Documentation

resave

Description

This function will save an RData file, if one does not exists it will create it.

Usage

resave(..., list = character(), file)

Arguments

list

List of files from your environment you want to save

file

Name of the RData file you want to save


alapo/mtr documentation built on April 4, 2022, 8:24 a.m.