| rename | R Documentation |
This function will create a directory if it doesnt exist, then copy the file and finally rename it. Most functions I have found will move the file and therein delete it. Which this function avoids.
rename(from, to)
from |
path where the files are coming from |
to |
path where you want the files to go to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.