| resave | R Documentation |
This function will save an RData file, if one does not exists it will create it.
resave(..., list = character(), file)
list |
List of files from your environment you want to save |
file |
Name of the RData file you want to save |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.